<div class="actions pull-right">
  {% for action in header_actions %}
  <a href="{{ action.url }}"
     title="{{ action.name }}"
     class="btn btn-default btn-lg btn-no-border {% if action.ajax_modal %}ajax-modal{% endif %}">
    {% if action.icon %}<span class="fa {{ action.icon }}"></span>{% endif %}
    {% if action.show_name %}{{ action.name }}{% endif %}
  </a>
  {% endfor %}
</div>
