{% extends 'infra_optim/base.html' %}
{% load i18n %}
{% block title %}{% trans 'Audits: ' %}{{ audits.name }}{% endblock %}
 
{% block page_header %}
  {% include 'horizon/common/_page_header.html' with title=_('Audits: ')|add:audits.name %}
{% endblock page_header %}
 
{% block main %}
<div class="row">
  <div class="col-md-4">
    <h4>{% trans "Hardware Info" %}</h4>
    <dl class="dl-horizontal dl-horizontal-left">
        <dt>{% trans "Severity" %}</dt>
        <dd>{{ audits.cpu_arch|default:_("-") }}</dd>
        <dt>{% trans "CPUs" %}</dt>
        <dd>{{ audits.vcpus|default:_("-") }}</dd>
        <dt>{% trans "Memory" %}</dt>
        <dd>{{ audits.ram_bytes|filesizeformat|default:_("-") }}</dd>
        <dt>{% trans "Disk" %}</dt>
        <dd>{{ audits.disk_bytes|filesizeformat|default:_("-") }}</dd>
    </dl>
  </div>
</div>
<div class="row">
  <div class="col-xs-12">
    {{ table.render }}
  </div>
</div>
 
{% endblock %}
