{% extends 'infra_optim/base.html' %}
{% load i18n %}
{% block title %}{% trans 'Actions: ' %}{{ action.uuid }}{% endblock %}

{% block page_header %}
  {% include 'horizon/common/_page_header.html' with title=_('Actions: ')|add:action.uuid %}
{% endblock page_header %}

{% block main %}
<div class="row">
  <div class="detail col-md-6">
    <h4>{% trans "Action Info" %}</h4>
    <dl class="dl-horizontal">
        <dt>{% trans "UUID" %}</dt>
        <dd>{{ action.uuid|default:_("-") }}</dd>
        <dt>{% trans "Type" %}</dt>
        <dd>{{ action.action_type|default:_("-") }}</dd>
        {% url 'horizon:admin:action_plans:detail' action.action_plan_uuid as action_plan_url %}
        <dt>{% trans "Action Plan" %}</dt>
        <dd><a href="{{ action_plan_url }}">
          {{ action.action_plan_uuid|default:_("-") }}
        </a></dd>
        <dt>{% trans "State" %}</dt>
        <dd>{{ action.state|default:_("-") }}</dd>
        <dt>{% trans "Created At" %}</dt>
        <dd>{{ action.created_at|parse_isotime|default:_("-") }}</dd>
        <dt>{% trans "Update At" %}</dt>
        <dd>{{ action.updated_at|parse_isotime|default:_("-") }}</dd>
    </dl>
  </div>
</div>
<div class="row">
  <div class="col-xs-12">
    {{ parameters_table.render }}
  </div>
</div>

{% endblock %}
