<div class="row">
  <div class="col-xs-2 col-xs-offset-3">{% include "infra_optim/_top_5_chart.html" with top_5=top_5.fan%}</div>
  <div class="col-xs-2">{% include "infra_optim/_top_5_chart.html" with top_5=top_5.voltage %}</div>
  <div class="col-xs-2">{% include "infra_optim/_top_5_chart.html" with top_5=top_5.temperature%}</div>
</div>
<div class="row">
  <div class="col-xs-2 col-xs-offset-3">{% include "infra_optim/_top_5_chart.html" with top_5=top_5.current %}</div>
</div>
