{% load i18n %}
{% with workflow.get_entry_point as entry_point %}
<div class="row">
  <form class="form form-horizontal col-xs-12" {{ workflow.attr_string|safe }} action="{{ workflow.get_absolute_url }}" {% if add_to_field %}data-add-to-field="{{ add_to_field }}"{% endif %} method="POST"{% if workflow.multipart %} enctype="multipart/form-data"{% endif %}>
    {% csrf_token %}
    {% if REDIRECT_URL %}<input type="hidden" name="{{ workflow.redirect_param_name }}" value="{{ REDIRECT_URL }}"/>{% endif %}
    <div class="fullscreen-workflow-body">
      <div class="actions pull-right">
      {% block workflow-buttons %}
        <input class="btn btn-primary pull-right"
               type="submit"
               value="{{ workflow.finalize_button_name }}">
      {% endblock %}
      </div>
      {% block workflow-body %}
      <ul class="nav nav-tabs">
        {% for step in workflow.steps %}
        <li class="{% if entry_point == step.slug %}active{% endif %}{% if step.has_errors %} error{% endif %}{% if step.has_required_fields %} required{% endif %}">
          <a href="#{{ step.get_id }}" data-toggle="tab" data-target="#{{ step.get_id }}">{{ step }}</a>
        </li>
        {% endfor %}
      </ul>
      <div class="tab-content">
        {% for step in workflow.steps %}
          <fieldset id="{{ step.get_id }}" class="js-tab-pane{% if entry_point == step.slug %} active{% endif %}">
            {{ step.render }}
          </fieldset>
          {% if not forloop.last %}
            <noscript><hr /></noscript>
          {% endif %}
        {% endfor %}
      </div>
      {% endblock %}
    </div>
  </form>
</div>
{% endwith %}
